@@ -46,6 +46,7 @@
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
+Q_DECLARE_METATYPE(Akonadi::Server::NotificationCollector*)
 
 TestScenario TestScenario::create(qint64 tag, TestScenario::Action action,
                                   const Protocol::Command &response)
@@ -117,6 +118,8 @@ FakeAkonadiServer::FakeAkonadiServer()
 FakeAkonadiServer::~FakeAkonadiServer()
 {
     delete mClient;
+    delete mConnection;
+    delete mNotificationSpy;
 }
 
 QString FakeAkonadiServer::basePath()
@@ -274,15 +277,14 @@ void FakeAkonadiServer::setScenarios(const TestScenario::List &scenarios)
 
 void FakeAkonadiServer::incomingConnection(quintptr socketDescriptor)
 {
-    QThread *thread = new QThread();
-    FakeConnection *connection = new FakeConnection(socketDescriptor, thread);
-    thread->start();
-
-    connect(connection, &Connection::disconnected, thread, &QThread::quit);
-    connect(thread, &QThread::finished, thread, &QObject::deleteLater);
-    connect(thread, &QThread::finished, connection, &QObject::deleteLater);
-
-    mNotificationSpy = new QSignalSpy(connection->notificationCollector(),
+    mConnection = new FakeConnection(socketDescriptor);
+    NotificationCollector *ntfCollector = Q_NULLPTR;
+    // Connection is it's own thread, so we have to make sure we get collector
+    // from DataStore of the Connection's thread, not ours
+    QMetaObject::invokeMethod(mConnection, "notificationCollector", Qt::BlockingQueuedConnection,
+                              Q_RETURN_ARG(Akonadi::Server::NotificationCollector*, ntfCollector));
+    Q_ASSERT(ntfCollector);
+    mNotificationSpy = new QSignalSpy(ntfCollector,
                                       SIGNAL(notify(Akonadi::Protocol::ChangeNotification::List)));
     Q_ASSERT(mNotificationSpy->isValid());
 }
@@ -307,13 +309,6 @@ void FakeAkonadiServer::runTest()
     close();
 }
 
-FakeDataStore *FakeAkonadiServer::dataStore() const
-{
-    Q_ASSERT_X(mDataStore, "FakeAkonadiServer::dataStore()",
-               "You have to call FakeAkonadiServer::start() first");
-    return mDataStore;
-}
-
 QSignalSpy *FakeAkonadiServer::notificationSpy() const
 {
     return mNotificationSpy;
