@@ -23,7 +23,6 @@
 
 #include "fakeakonadiserver.h"
 #include "aktest.h"
-#include "akdebug.h"
 #include "entities.h"
 
 #include <private/scope_p.h>
@@ -46,8 +45,8 @@ public:
         try {
             FakeAkonadiServer::instance()->init();
         } catch (const FakeAkonadiServerException &e) {
-            akError() << "Server exception: " << e.what();
-            akFatal() << "Fake Akonadi Server failed to start up, aborting test";
+            qWarning() << "Server exception: " << e.what();
+            qFatal("Fake Akonadi Server failed to start up, aborting test");
         }
     }
 
