@@ -72,6 +72,7 @@ static CollectionFetchJob::Type getFetchType(EntityTreeModel::CollectionFetchStr
 
 EntityTreeModelPrivate::EntityTreeModelPrivate(EntityTreeModel *parent)
     : q_ptr(parent)
+    , m_monitor(nullptr)
     , m_rootNode(0)
     , m_collectionFetchStrategy(EntityTreeModel::FetchCollectionsRecursive)
     , m_itemPopulation(EntityTreeModel::ImmediatePopulation)
@@ -97,6 +98,7 @@ EntityTreeModelPrivate::~EntityTreeModelPrivate()
 void EntityTreeModelPrivate::init(ChangeRecorder *monitor)
 {
     Q_Q(EntityTreeModel);
+    Q_ASSERT(!m_monitor);
     m_monitor = monitor;
     // The default is to FetchCollectionsRecursive, so we tell the monitor to fetch collections
     // That way update signals from the monitor will contain the full collection.
@@ -582,7 +584,7 @@ void EntityTreeModelPrivate::monitoredCollectionsChanged(const Akonadi::Collecti
         fetchCollections(collection, CollectionFetchJob::Base);
         fetchCollections(collection, fetchType);
     } else {
-        //If a collection is derefernced and no longer explicitly monitored it might still match other filters
+        //If a collection is dereferenced and no longer explicitly monitored it might still match other filters
         if (!shouldBePartOfModel(collection)) {
             monitoredCollectionRemoved(collection);
         }
@@ -839,7 +841,7 @@ void EntityTreeModelPrivate::monitoredCollectionAdded(const Akonadi::Collection
 
 void EntityTreeModelPrivate::monitoredCollectionRemoved(const Akonadi::Collection &collection)
 {
-    //if an explictly monitored collection is removed, we would also have to remove collections which were included to show it (as in the move case)
+    //if an explicitly monitored collection is removed, we would also have to remove collections which were included to show it (as in the move case)
     if ((collection == m_rootCollection) ||
             m_monitor->collectionsMonitored().contains(collection)) {
         beginResetModel();
