@@ -54,13 +54,9 @@ bool AkAppend::buildPimItem(const Protocol::CreateItemCommand &cmd, PimItem &ite
         return failureResponse("Cannot append item into virtual collection");
     }
 
-    MimeType mimeType = MimeType::retrieveByName(cmd.mimeType());
+    MimeType mimeType = MimeType::retrieveByNameOrCreate(cmd.mimeType());
     if (!mimeType.isValid()) {
-        MimeType m(cmd.mimeType());
-        if (!m.insert()) {
-            return failureResponse(QStringLiteral("Unable to create mimetype '") % cmd.mimeType() % QStringLiteral("'."));
-        }
-        mimeType = m;
+        return failureResponse(QStringLiteral("Unable to create mimetype '") % cmd.mimeType() % QStringLiteral("'."));
     }
 
     item.setRev(0);
@@ -409,9 +405,9 @@ bool AkAppend::parseStream()
             }
             storageTrx.commit();
         } else {
-            akDebug() << "Multiple merge candidates:";
+            qCDebug(AKONADISERVER_LOG) << "Multiple merge candidates:";
             Q_FOREACH (const PimItem &item, result) {
-                akDebug() << "\t ID: " << item.id() << ", RID:" << item.remoteId() << ", GID:" << item.gid();
+                qCDebug(AKONADISERVER_LOG) << "\t ID: " << item.id() << ", RID:" << item.remoteId() << ", GID:" << item.gid();
             }
             // Nor GID or RID are guaranteed to be unique, so make sure we don't merge
             // something we don't want
